GrovsPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • GrovsPlatform
Implementers

Constructors

GrovsPlatform()
Constructs a GrovsPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
onDeeplinkReceived → Stream<DeeplinkDetails>
Stream of deeplink events
no setter
onError → Stream<GrovsError>
Stream of asynchronous SDK errors, available on iOS only.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

Generate a Grovs link with the specified parameters
getPlatformVersion() → Future<String?>
logCustomPurchase({required TransactionType type, required int priceInCents, required String currency, required String productId, DateTime? startDate}) → Future<void>
Log a custom purchase
logInAppPurchase(String transactionId) → Future<void>
Log an in-app purchase from the platform store
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDebugLevel(String level) → Future<void>
Set debug level
setGlobalTags(List<String>? tags) → Future<void>
Set tags applied to every subsequent custom event
setPushToken(String token) → Future<void>
Set the push token for receiving push notifications
setScreenAliases(Map<String, String> aliases) → Future<void>
Sync a map of raw screen names to friendly names
setSDK(bool enabled) → Future<void>
Enable or disable the native SDK.
setUserAttributes(Map<String, dynamic> attributes) → Future<void>
Set user attributes
setUserIdentifier(String identifier) → Future<void>
Set user identifier
toString() → String
A string representation of this object.
inherited
track(String name, {Map<String, dynamic>? properties, List<String>? tags}) → Future<void>
Log a custom analytics event
trackScreenView(String screenName, {Map<String, dynamic>? properties}) → Future<void>
Log a manual screen view

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ GrovsPlatform
The default instance of GrovsPlatform to use.
getter/setter pair