CustomLinkRedirect class

Custom link redirect configuration

Constructors

CustomLinkRedirect({required String url, bool openAppIfInstalled = true})

Properties

hashCode → int
The hash code for this object.
no setterinherited
openAppIfInstalled → bool
Whether to open the app if installed (default: true) true: if the app is installed it will handle the link false: even if the app is installed, the link should be opened in the browser
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
The URL to redirect to
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited