GenerateLinkParams class

Parameters for generating a Grovs link

Constructors

GenerateLinkParams({required String title, String? subtitle, String? imageURL, Map<String, dynamic>? data, List<String>? tags, CustomRedirects? customRedirects, bool? showPreviewIos, bool? showPreviewAndroid, bool? copyToClipboardIos, bool? copyToClipboardAndroid, TrackingParams? tracking})

Properties

copyToClipboardAndroid → bool?
Whether the Android link preview copies the link to the clipboard. Null uses the project default.
final
copyToClipboardIos → bool?
Whether the iOS link preview copies the link to the clipboard. Null uses the project default.
final
customRedirects → CustomRedirects?
Custom redirect URLs for different platforms
final
data → Map<String, dynamic>?
Custom data to be passed with the link
final
hashCode → int
The hash code for this object.
no setterinherited
imageURL → String?
URL to an image for the link preview
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showPreviewAndroid → bool?
Whether to show preview on Android
final
showPreviewIos → bool?
Whether to show preview on iOS
final
subtitle → String?
The subtitle of the link
final
tags → List<String>?
Tags for organizing links
final
title → String
The title of the link
final
tracking → TrackingParams?
Tracking parameters for UTM analytics
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited