copyToClipboardAndroid property
Whether the Android link preview copies the link to the clipboard. Null uses the project default.
Implementation
final bool? copyToClipboardAndroid;
Whether the Android link preview copies the link to the clipboard. Null uses the project default.
final bool? copyToClipboardAndroid;