copyToClipboardIos property
Whether the iOS link preview copies the link to the clipboard. Null uses the project default.
Implementation
final bool? copyToClipboardIos;
Whether the iOS link preview copies the link to the clipboard. Null uses the project default.
final bool? copyToClipboardIos;