GrovsErrorCode enum

Native SDK error categories reported through the error stream.

Inheritance
Available extensions

Values

authenticationFailed → const GrovsErrorCode
const GrovsErrorCode('authentication_failed')
networkRequestFailed → const GrovsErrorCode
const GrovsErrorCode('network_request_failed')
eventDispatchFailed → const GrovsErrorCode
const GrovsErrorCode('event_dispatch_failed')
linkGenerationFailed → const GrovsErrorCode
const GrovsErrorCode('link_generation_failed')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nativeName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromNativeName(String? name) → GrovsErrorCode?
Returns null for missing or unsupported native error codes.

Constants

values → const List<GrovsErrorCode>
A constant List of the values in this enum, in order of their declaration.