TrackingParams class

Tracking parameters for UTM analytics

Constructors

TrackingParams({String? utmCampaign, String? utmSource, String? utmMedium})
TrackingParams.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
utmCampaign → String?
UTM campaign parameter
final
utmMedium → String?
UTM medium parameter
final
utmSource → String?
UTM source parameter
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited