MethodChannelGrovs class
An implementation of GrovsPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- GrovsPlatform
- MethodChannelGrovs
Constructors
Properties
- errorChannel → EventChannel
-
The event channel for receiving asynchronous SDK errors.
final
- eventChannel → EventChannel
-
The event channel for receiving deeplink events
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
-
onDeeplinkReceived
→ Stream<
DeeplinkDetails> -
Stream of deeplink events
no setteroverride
-
onError
→ Stream<
GrovsError> -
Stream of asynchronous SDK errors, available on iOS only.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateLink(
GenerateLinkParams params) → Future< String> -
Generate a Grovs link with the specified parameters
override
-
getPlatformVersion(
) → Future< String?> -
override
-
logCustomPurchase(
{required TransactionType type, required int priceInCents, required String currency, required String productId, DateTime? startDate}) → Future< void> -
Log a custom purchase
override
-
logInAppPurchase(
String transactionId) → Future< void> -
Log an in-app purchase from the platform store
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDebugLevel(
String level) → Future< void> -
Set debug level
override
-
setGlobalTags(
List< String> ? tags) → Future<void> -
Set tags applied to every subsequent custom event
override
-
setPushToken(
String token) → Future< void> -
Set the push token for receiving push notifications
override
-
setScreenAliases(
Map< String, String> aliases) → Future<void> -
Sync a map of raw screen names to friendly names
override
-
setSDK(
bool enabled) → Future< void> -
Enable or disable the native SDK.
override
-
setUserAttributes(
Map< String, dynamic> attributes) → Future<void> -
Set user attributes
override
-
setUserIdentifier(
String identifier) → Future< void> -
Set user identifier
override
-
toString(
) → String -
A string representation of this object.
inherited
-
track(
String name, {Map< String, dynamic> ? properties, List<String> ? tags}) → Future<void> -
Log a custom analytics event
override
-
trackScreenView(
String screenName, {Map< String, dynamic> ? properties}) → Future<void> -
Log a manual screen view
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited