DeeplinkDetails class
Represents the details of a deeplink received from Grovs
Constructors
-
DeeplinkDetails({String? link, Map<
String, dynamic> ? data, TrackingParams? tracking}) - DeeplinkDetails.fromMap(Map map)
-
factory
Properties
-
data
→ Map<
String, dynamic> ? -
The payload data associated with the deeplink
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- link → String?
-
The deeplink URL
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tracking → TrackingParams?
-
The tracking parameters associated with the deeplink
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited